@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from dev0s.classes.exceptions import Exceptions
-from dev0s.classes.files import *
+from dev0s.classes.defaults.exceptions import Exceptions
+from dev0s.classes.defaults.files import *
 from dev0s.classes.utils.copycats import Docs
 
 # pip imports.
@@ -12,13 +12,13 @@ import json as pypi_json
 import traceback as _traceback_
 
 # the response manager class.
-class __Response__(Docs):
+class Response(object):
 	def __init__(self):	
 
 		# docs.
 		Docs.__init__(self,
 			initialized=True,
-			module="Response", 
+			module="dev0s.response", 
 			notes=[], )
 
 		# set log file.
@@ -47,7 +47,7 @@ class __Response__(Docs):
 		required_log_level=None, 
 		# save the error to the logs file.
 		save=False,
-		# return as a django JsonResponse.
+		# return as a django Jsonresponse.
 		django=False,
 	):
 		response = self.response({
@@ -73,7 +73,7 @@ class __Response__(Docs):
 		required_log_level=None, 
 		# save the error to the erros file.
 		save=False,
-		# return as a django JsonResponse.
+		# return as a django Jsonresponse.
 		django=False,
 		# raise error for developer traceback.
 		traceback=ERROR_TRACEBACK,
@@ -129,9 +129,9 @@ class __Response__(Docs):
 				else:
 					msg = msg
 			elif mode == "warning":
-				msg = f"&RED&:Warning&END&: {msg}"
+				msg = f"&RED&Warning&END&: {msg}"
 			elif mode == "alert":
-				msg = f"&ORANGE&:Alert&END&: {msg}"
+				msg = f"&ORANGE&Alert&END&: {msg}"
 			return msg
 			#
 		msg, _error_ = None, False
@@ -159,7 +159,7 @@ class __Response__(Docs):
 			comparison = log_level != None and log_level >= required_log_level
 		except TypeError as e:
 			if "not supported between instances of 'dict' and 'int'" in f"{e}":
-				raise TypeError(f"You most likely returned a Response.error when you meant a Response.success, error: {e}")
+				raise TypeError(f"You most likely returned a response.error when you meant a response.success, error: {e}")
 			else:
 				raise TypeError(e)
 		if comparison:
@@ -174,9 +174,9 @@ class __Response__(Docs):
 			else:
 				print(f"{color.fill(msg)}")
 		if save: 
-			self.__log_to_file__(msg)
+			self.log_to_file(msg)
 		elif save_errors and _error_:
-			self.__log_to_file__(msg)
+			self.log_to_file(msg)
 
 		#
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
@@ -224,16 +224,16 @@ class __Response__(Docs):
 			#	#print(f"Serialized generator output instance: [{response.__class__.__name__}].")
 			#	#return response
 			#except Eception as e:
-			#	return Response.error(f"An error occured during the execution of generator [{response}], error: {e}")
+			#	return _response_.error(f"An error occured during the execution of generator [{response}], error: {e}")
 
 		# check ResponseObject.
 		elif response.__class__.__name__ in ["ResponseObject"]:
 			return response
 		
-		# check Console.Output.
-		elif response.__class__.__name__ in ["Output"]:
+		# check Output.
+		elif response.__class__.__name__ in ["OutputObject"]:
 			try:
-				return response.response()
+				return _response_.response()
 			except AttributeError:
 				return response
 
@@ -316,10 +316,6 @@ class __Response__(Docs):
 			response["error"] = f"Failed to log the message, error: {e}."
 			return response
 			
-		#
-	def __log_to_file__(self, message, raw=False):
-		self.log("Depricated, Response.__log_to_file__ has moved to Response.log_to_file", mode="alert")
-		return self.log_to_file(message, raw=raw)
 		#
 	def __serialize__(self, variable):
 		if isinstance(variable, (dict,Dictionary)):
@@ -342,13 +338,13 @@ class __Response__(Docs):
 	#
 	
 # the parameters manager object class.
-class Parameters(Docs):
+class Parameters(object):
 	def __init__(self):
 		
 		# docs.
 		Docs.__init__(self,
 			initialized=True,
-			module="Response.parameters", 
+			module="dev0s.response.parameters", 
 			notes=[], )
 
 		#
@@ -361,18 +357,15 @@ class Parameters(Docs):
 		#	list instance: return a parameters object & return an error response when a parameter is undefined.
 		#	dict instance: return a parameters object & return the parameter's value from the dict as a default when undefined.
 		parameters=[], 
-		# default return value (dict instance of parameters overwrites the default parameter).
-		default=None, 
 		# traceback id.
 		traceback=None,
 	):
 		if request == None:
-			raise Exceptions.InvalidUsage("<Response.paramters.get>: Define parameter: [request].")
+			raise Exceptions.InvalidUsage("<dev0s.response.paramters.get>: Define parameter: [request].")
 		
 		# single parameter.
 		if isinstance(parameters, (str,String)):
 			parameters = str(parameters)
-			response = Response.response()
 			format = None
 			if ":" in parameters:
 				parameters,format = parameters.split(":")
@@ -385,22 +378,23 @@ class Parameters(Docs):
 				variable = request.GET.get(parameters)
 			if variable in ["", None]:
 				if traceback != None:
-					return variable, Response.error(f"{traceback}: Define parameter: [{parameters}].")
+					return variable, _response_.error(f"{traceback}: Define parameter: [{parameters}].")
 				else:
-					return variable, Response.error(f"Define parameter: [{parameters}].")
+					return variable, _response_.error(f"Define parameter: [{parameters}].")
 			elif format != None:
-				if format in ["str", "string"]: variable = str(variable)
-				elif format in ["int", "integer"]: variable = int(variable)
-				elif format in ["bool", "boolean"]: 
+				if format.lower() in ["str", "string"]: variable = str(variable)
+				elif format.lower() in ["int", "integer"]: variable = int(variable)
+				elif format.lower() in ["bool", "boolean"]: 
 					if variable in ["true", "True", "TRUE", True]: variable = True
 					else: variable = False
-				elif format in ["float", "double"]: variable = float(variable)
-				elif format in ["array", "list"]: variable = variable.split(",")
+				elif format.lower() in ["float", "double"]: variable = float(variable)
+				elif format.lower() in ["array", "list"]: variable = variable.split(",")
 				else:
-					raise ValueError(f"Unrecognized <Response.parameters.get> format: {format}.")
-			
+					raise ValueError(f"Unrecognized <dev0s.response.parameters.get> format: {format}.")
+			if variable == "None": variable = None
+
 			# handler.
-			return variable, Response.success(f"Succesfully retrieved request parameter [{parameters}].", {
+			return variable, _response_.success(f"Succesfully retrieved request parameter [{parameters}].", {
 				"key":parameters,
 				"value":variable,
 			})
@@ -414,7 +408,7 @@ class Parameters(Docs):
 				param = param.split(":")[0]
 				if response["error"] != None: 
 					if optional:
-						params[param] = default
+						params[param] = None
 					else:
 						return params, response
 				else: 
@@ -422,8 +416,8 @@ class Parameters(Docs):
 			if optional:
 				for key in parameters:
 					try: params[key]
-					except: params[key] = default
-			return params, Response.success(f"Succesfully retrieved {len(params)} request parameter(s).")
+					except: params[key] = None
+			return params, _response_.success(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 		# dict recursive.
 		elif isinstance(parameters, (dict, Dictionary, ResponseObject)):
@@ -444,7 +438,7 @@ class Parameters(Docs):
 				for key,default in parameters.items():
 					try: params[key]
 					except: params[key] = default
-			return params, Response.success(f"Succesfully retrieved {len(params)} request parameter(s).")
+			return params, _response_.success(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 
 		# invalid.
@@ -468,9 +462,9 @@ class Parameters(Docs):
 			name,parameter = parameters
 			if parameter == default: 
 				if traceback != None:
-					return Response.error(f"{traceback}: Define parameter [{name}].")
+					return _response_.error(f"{traceback}: Define parameter [{name}].")
 				else:
-					return Response.error(f"Define parameter [{name}].")
+					return _response_.error(f"Define parameter [{name}].")
 			if ":" in name:
 				name,formats = name.split(":")
 				while True:
@@ -479,15 +473,15 @@ class Parameters(Docs):
 				formats = formats.split(",")
 				param_format = Formats.get(parameter, serialize=True)
 				if param_format not in formats:
-					return Response.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Array(path=False, array=formats).string(joiner=', ')}.")
-			return Response.success(f"Succesfully checked parameter [{name}].")
+					return _response_.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Array(path=False, array=formats).string(joiner=', ')}.")
+			return _response_.success(f"Succesfully checked parameter [{name}].")
 
 		# recursive.
 		elif isinstance(parameters, (dict,Dictionary,ResponseObject)):
 			for id, value in parameters.items():
 				response = self.check(parameters=(id, value), default=default, traceback=traceback)
 				if response["error"] != None: return response
-			return Response.success(f"Succesfully checked {len(parameters)} parameter(s).")
+			return _response_.success(f"Succesfully checked {len(parameters)} parameter(s).")
 		# invalid.
 		else: 
 			raise Exceptions.InstanceError(f"Parameter [parameters] requires to be a [dict, Dictionary, tuple] not [{parameters.__class__.__name__}].")
@@ -500,7 +494,7 @@ class Parameters(Docs):
 class ResponseObject(object):
 	def __init__(self, 
 		#
-		# Should be initialized with Response.success or Response.error.
+		# Should be initialized with response.success or response.error.
 		#
 		# the response attributes (dict or dict in str format).
 		attributes={
@@ -528,35 +522,38 @@ class ResponseObject(object):
 		else:
 			raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
 
-		# clean message & error.
-		if self.message != None: self.message = String(self.message).capitalized_word()
-		if self.error != None: self.error = String(self.error).capitalized_word()
-		while True:
-			if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
-				self.message = self.message[:-1]
-			elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
-				self.error = self.error[:-1]
-			elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
-				self.error = String(self.error[len("Error: "):]).capitalized_word()
-			elif self.error != None and len(self.error) >= len("..") and String(self.error).last("..") in [".."]:
-				self.error = str(String(self.error).remove_last("."))
-			else: break
-		
-		# add dot.
-		if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
-			self.message += "."
-		if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
-			self.error += "."
+		# catch error so you can also init custom ResponseObjects.
+		try:
+
+			# clean message & error.
+			if self.message != None: self.message = String(self.message).capitalized_word()
+			if self.error != None: self.error = String(self.error).capitalized_word()
+			while True:
+				if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
+					self.message = self.message[:-1]
+				elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
+					self.error = self.error[:-1]
+				elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
+					self.error = String(self.error[len("Error: "):]).capitalized_word()
+				elif self.error != None and len(self.error) >= len("..") and String(self.error).last("..") in [".."]:
+					self.error = str(String(self.error).remove_last("."))
+				else: break
+			
+			# add dot.
+			if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
+				self.message += "."
+			if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
+				self.error += "."
 
 
-		# check error passed as success response. & reversed
-		if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
-			#_traceback_.print_exc() 
-			raise ValueError("A success response may not start with (failed ...). You most likely called an Response.success return while you meant Response.error.")
-		if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
-			#_traceback_.print_exc() 
-			raise ValueError("An error response may not start with (success ...). You most likely called an Response.error return while you meant Response.success.")
-		
+			# check error passed as success response. & reversed
+			if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
+				#_traceback_.print_exc() 
+				raise ValueError("A success response may not start with (failed ...). You most likely called an response.success return while you meant response.error.")
+			if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
+				#_traceback_.print_exc() 
+				raise ValueError("An error response may not start with (success ...). You most likely called an response.error return while you meant response.success.")
+		except AttributeError: a=1 
 		#
 	# clean default values.
 	def clean(self, 
@@ -592,16 +589,17 @@ class ResponseObject(object):
 	# assign dict.
 	def assign(self, dictionary):
 		if isinstance(dictionary, (dict, Dictionary)):
-			for key,value in Response.__serialize__(dictionary).items():
+			for key,value in response.__serialize__(dictionary).items():
 				self[key] = value
 		elif isinstance(dictionary, (tuple, list, Array)):
 			for key,value in dictionary:
-				self[key] = Response.__serialize__(value)
+				self[key] = response.__serialize__(value)
 		else:
 			raise Exceptions.InvalidUsage("The dictionary parameter must be a dict or tuple.")
 		return self
 	# crash the error message.
-	def crash(self, error="ValueError", traceback=True, json=False):
+	def crash(self, error="ValueError", traceback=True, json=False, error_only=False):
+		if error_only and self["error"] == None: return None
 		if json:
 			self.log(error=self["error"], json=json)
 			sys.exit(1)
@@ -622,13 +620,13 @@ class ResponseObject(object):
 		#   unpack all keys from the dict & when not present return the key's value as default.
 		keys,
 	):
-		defaults = {}
+		defaults_ = {}
 		if isinstance(keys, (dict, Files.Dictionary, ResponseObject)):
 			if isinstance(keys, dict):
-				defaults = dict(keys)
+				defaults_ = dict(keys)
 				keys = list(keys.keys())
 			else:
-				defaults = keys.dict()
+				defaults_ = keys.dict()
 				keys = keys.keys()
 		elif isinstance(keys, str):
 			keys = [keys]
@@ -639,7 +637,7 @@ class ResponseObject(object):
 				value = self[key]
 			except KeyError: 
 				try:
-					value = defaults[key]
+					value = defaults_[key]
 				except KeyError: 
 					set = False
 			if not set:
@@ -828,11 +826,12 @@ class ResponseObject(object):
 	# return raw data.
 	def raw(self):
 		return self.dict()
-	# return response self for Console.Output and other objects that init ResponseObject as self and want it to be converted to response.
+	# return response self for OutputObject and other objects that init ResponseObject as self and want it to be converted to response.
 	def response(self):
 		return self
 		#
 
 # initialized objects.
 # must be initialized as Response since object class Parameters requires it.
-Response = __Response__()
+response = Response()
+_response_ = response
